# Changelog

## 0.1.0-alpha.3 (2025-01-28)

Full Changelog: [v0.1.0-alpha.2...v0.1.0-alpha.3](https://github.com/DatagridAI/datagrid-python/compare/v0.1.0-alpha.2...v0.1.0-alpha.3)

### Chores

* go live ([#6](https://github.com/DatagridAI/datagrid-python/issues/6)) ([75ac964](https://github.com/DatagridAI/datagrid-python/commit/75ac96490178d1214d15741c9a12e2e3868b6703))
* update SDK settings ([#8](https://github.com/DatagridAI/datagrid-python/issues/8)) ([7370457](https://github.com/DatagridAI/datagrid-python/commit/7370457e992a180d2ea42d8499402e30b6d774b2))

## 0.1.0-alpha.2 (2025-01-27)

Full Changelog: [v0.1.0-alpha.1...v0.1.0-alpha.2](https://github.com/DatagridAI/datagrid-python/compare/v0.1.0-alpha.1...v0.1.0-alpha.2)

### Features

* **api:** api update ([93fb0d4](https://github.com/DatagridAI/datagrid-python/commit/93fb0d4e4e1dc6e5172429515e70aad79e0ad6e2))
* **api:** api update ([941cf45](https://github.com/DatagridAI/datagrid-python/commit/941cf4546e4878e8489756c98c2570c98f570f6c))
* **api:** api update ([66b6770](https://github.com/DatagridAI/datagrid-python/commit/66b6770bdde6d3a77ed50613b25fcb1fb33220d4))
* **api:** manual updates ([97e0bd5](https://github.com/DatagridAI/datagrid-python/commit/97e0bd582eb2428bd0abd8423e8c90995b0654f8))
* **api:** manual updates ([2b17522](https://github.com/DatagridAI/datagrid-python/commit/2b17522f5b743047bba597447667fbdcd302fdf4))
* sse converse ([d771e3b](https://github.com/DatagridAI/datagrid-python/commit/d771e3bbcbc2cf0be4f368d0d1ab56a523b88c81))
* sse converse ([d771e3b](https://github.com/DatagridAI/datagrid-python/commit/d771e3bbcbc2cf0be4f368d0d1ab56a523b88c81))
* support for SSE converse ([0e95ca4](https://github.com/DatagridAI/datagrid-python/commit/0e95ca428a7593a13a7be1f47256aef30ff9b3e9))


### Bug Fixes

* proper header ([710309f](https://github.com/DatagridAI/datagrid-python/commit/710309ffd9ed01d181d5d44368454d63c6285a7a))
* rm docstring from the overloaded def ([75b11ce](https://github.com/DatagridAI/datagrid-python/commit/75b11ceac6c49277ca3e0f51b9648d061077793c))
* tests ([94160e8](https://github.com/DatagridAI/datagrid-python/commit/94160e8dac5014ea368517637ad7180b0ed514f2))


### Chores

* go live ([#1](https://github.com/DatagridAI/datagrid-python/issues/1)) ([b608c44](https://github.com/DatagridAI/datagrid-python/commit/b608c44014061206cd2a0b2023fd6fe715107bfb))
* go live ([#3](https://github.com/DatagridAI/datagrid-python/issues/3)) ([31dd324](https://github.com/DatagridAI/datagrid-python/commit/31dd324ceb90b1c9a7d546ed984bee88c5dbc1ca))
* **internal:** codegen related update ([3cd8e1a](https://github.com/DatagridAI/datagrid-python/commit/3cd8e1afe81e4c438b663a1022677045fa052cd8))
* **internal:** minor formatting changes ([1608034](https://github.com/DatagridAI/datagrid-python/commit/16080345f25c83d34a2fbd2250741f061aedae6c))
* update SDK settings ([#4](https://github.com/DatagridAI/datagrid-python/issues/4)) ([acd7f70](https://github.com/DatagridAI/datagrid-python/commit/acd7f70e749b1c9dad7df54fe1a1b64f4d42ffe8))

## 0.1.0-alpha.1 (2025-01-15)

Full Changelog: [v0.0.1-alpha.0...v0.1.0-alpha.1](https://github.com/ToricLabs/datagrid-python/compare/v0.0.1-alpha.0...v0.1.0-alpha.1)

### Features

* **api:** api update ([b5d6a8c](https://github.com/ToricLabs/datagrid-python/commit/b5d6a8ca109ee89ad067c52bc2a9742e77e438b8))
* **api:** update via SDK Studio ([9b8b99d](https://github.com/ToricLabs/datagrid-python/commit/9b8b99de5655c824bba0cd1c39ebe86d111e7fda))
* **api:** update via SDK Studio ([4356f22](https://github.com/ToricLabs/datagrid-python/commit/4356f2273f8df43faa7e72caf384a717aeb11283))


### Bug Fixes

* **client:** only call .close() when needed ([49224f5](https://github.com/ToricLabs/datagrid-python/commit/49224f551ffa1cf522b8f915c0150f6b0ccec8b3))
* correctly handle deserialising `cls` fields ([4e06990](https://github.com/ToricLabs/datagrid-python/commit/4e06990be5b8fb76cad39b97dafb0a7b350c45f8))


### Chores

* go live ([#1](https://github.com/ToricLabs/datagrid-python/issues/1)) ([379ce7a](https://github.com/ToricLabs/datagrid-python/commit/379ce7a02b84a30151f647b86ff1ba94d6f1d695))
* **internal:** bump httpx dependency ([413952c](https://github.com/ToricLabs/datagrid-python/commit/413952c264538f97d317c95d87876cb058d64c8d))
* **internal:** codegen related update ([b38e485](https://github.com/ToricLabs/datagrid-python/commit/b38e48539cf573deb543c5a4b3e1c9a001494c6b))
* **internal:** codegen related update ([8e61214](https://github.com/ToricLabs/datagrid-python/commit/8e61214d9e0c146005e00bf1dfdd3563af952acd))
* **internal:** codegen related update ([a2a5915](https://github.com/ToricLabs/datagrid-python/commit/a2a5915b64fc7c52da27ffb39f95d63e7b39e69c))
* **internal:** codegen related update ([e44f3ba](https://github.com/ToricLabs/datagrid-python/commit/e44f3ba933e4c22292f33126ffd804e7459c4331))
* **internal:** codegen related update ([31f7bfd](https://github.com/ToricLabs/datagrid-python/commit/31f7bfdeabb11f65d7c4c6548475b1a856147c11))
* **internal:** codegen related update ([6597ed4](https://github.com/ToricLabs/datagrid-python/commit/6597ed414dcb7e2a1bd03163f3bf26fa7d0ba27f))
* **internal:** fix some typos ([d7bf113](https://github.com/ToricLabs/datagrid-python/commit/d7bf11367981380729d2eee052e0bcd5bc2c5837))
* update SDK settings ([#3](https://github.com/ToricLabs/datagrid-python/issues/3)) ([dd5ded3](https://github.com/ToricLabs/datagrid-python/commit/dd5ded35ca67baa02693285fcde3f5ac85d8feee))


### Documentation

* fix typos ([647dc35](https://github.com/ToricLabs/datagrid-python/commit/647dc35d4c22fcf7964b5df9e512b6213c6ed71b))
* **readme:** example snippet for client context manager ([34d4dc9](https://github.com/ToricLabs/datagrid-python/commit/34d4dc9bf14f6d6aef814c7055a415873bc3aef5))
